@@ -4,6 +4,7 @@ from os import stat
 from re import sub
 from typing import Callable
 from typing import Optional
+from typing import Union
 
 from falocalrepo_database import FADatabase
 from falocalrepo_database import FADatabaseTable
@@ -73,7 +74,7 @@ def load_prev_next(db_path: str, table: str, item_id: int, _cache=None) -> tuple
     with FADatabase(db_path) as db:
         item: Optional[dict] = db[table][item_id]
         return db[table].select(
-            {"AUTHOR": item["AUTHOR"]},
+            {"AUTHOR": item["AUTHOR"], **({"folder": item["FOLDER"]} if table == submissions_table else {})},
             ["LAG(ID, 1, 0) over (order by ID)", "LEAD(ID, 1, 0) over (order by ID)"],
             order=[f"ABS(ID - {item_id})"],
             limit=1
@@ -108,7 +109,7 @@ def load_search(db_path: str, table: str, sort: str, order: str, params_: str =
             query = sub(r"any(?= +(!?=|(not +)?(like|glob)|[<>]=?))", f"({'||'.join(cols_table)})", query)
             return (
                 list(db_table.select_sql(query, columns=cols_results, order=[f"{sort} {order}"])),
-                cols_table + ["any"],
+                cols_table,
                 cols_results,
                 cols_list,
                 col_id,
@@ -126,7 +127,7 @@ def load_search(db_path: str, table: str, sort: str, order: str, params_: str =
 
         return (
             list(db_table.select(params, cols_results, like=True, order=[f"{sort} {order}"])),
-            cols_table + ["any"],
+            cols_table,
             cols_results,
             cols_list,
             col_id,
